@@ -1,7 +1,7 @@
 package Log::ger::Output::Composite;
 
 our $DATE = '2017-07-02'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
@@ -135,8 +135,15 @@ sub get_hooks {
 
                 # put the data that are mentioned in string-eval'ed code in a
                 # package so they are addressable
-                my ($addr) = "$loggers" =~ /\(0x(\w+)/;
-                my $varname = "Log::ger::Stash::$addr";
+                my $varname = do {
+                    my $suffix;
+                    if ($args{target} eq 'package') {
+                        $suffix = $args{target_arg};
+                    } else {
+                        ($suffix) = "$args{target_arg}" =~ /\(0x(\w+)/;
+                    }
+                    "Log::ger::Stash::OComposite_$suffix";
+                };
                 {
                     no strict 'refs';
                     ${$varname} = [];
@@ -237,7 +244,7 @@ Log::ger::Output::Composite - Composite output
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
